==> jc-1.4.0.tar.gz: javax/swing/text/html/HTML__24UnknownTag.c <==
// public class javax.swing.text.html.HTML$UnknownTag

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 57b76034fa05fce javax_swing_text_html_HTML
// @dep_class e195b3a296492665 javax_swing_text_html_HTML__24Tag
// @dep_class 51da1f48373035e8 javax_swing_text_html_HTML__24UnknownTag

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_text_html_HTML
// @dep_header javax_swing_text_html_HTML__24UnknownTag

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/text/html/HTML.h"
#include "javax/swing/text/html/HTML__24UnknownTag.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private static final long serialVersionUID
static const jlong _jc_javax_swing_text_html_HTML__24UnknownTag$initial_value$serialVersionUID = _JC_JLONG(-1534369342247250625);
static _jc_field _jc_javax_swing_text_html_HTML__24UnknownTag$field_info$serialVersionUID = {
	.name=		"serialVersionUID",
	.signature=	"J",
	.class=		&_jc_javax_swing_text_html_HTML__24UnknownTag$type,
	.type=		&_jc_long$prim$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_text_html_HTML__24UnknownTag$fields_struct, serialVersionUID),
	.initial_value=	&_jc_javax_swing_text_html_HTML__24UnknownTag$initial_value$serialVersionUID,
};

// Fields
static _jc_field *const _jc_javax_swing_text_html_HTML__24UnknownTag$fields[] = {
	&_jc_javax_swing_text_html_HTML__24UnknownTag$field_info$serialVersionUID
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String)
//

static _jc_linenum _jc_javax_swing_text_html_HTML__24UnknownTag$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_javax_swing_text_html_HTML__24UnknownTag$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_swing_text_html_HTML__24UnknownTag$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_javax_swing_text_html_HTML__24UnknownTag$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_javax_swing_text_html_HTML__24UnknownTag$type,
	.param_types=		&_jc_javax_swing_text_html_HTML__24UnknownTag$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_text_html_HTML__24UnknownTag$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_text_html_HTML__24UnknownTag$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_text_html_HTML__24UnknownTag$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_text_html_HTML__24UnknownTag, _init$c31b894660454d13);

void
_jc_javax_swing_text_html_HTML__24UnknownTag$method$_init$c31b894660454d13(_jc_env *const env, _jc_javax_swing_text_html_HTML__24UnknownTag$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_javax_swing_text_html_HTML__24UnknownTag$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	r1 = param0;
	_JC_REF_FIELD(env, r0, javax_swing_text_html_HTML__24Tag, id) = r1;
	_JC_LINE_NUMBER(70);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_text_html_HTML__24UnknownTag$methods[] = {
	&_jc_javax_swing_text_html_HTML__24UnknownTag$method_info$_init$c31b894660454d13
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_javax_swing_text_html_HTML__24UnknownTag$fields_struct _jc_javax_swing_text_html_HTML__24UnknownTag$class_fields = { };

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_javax_swing_text_html_HTML__24UnknownTag$interfaces[] = {
	&_jc_java_io_Serializable$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_101[] = {
	&_jc_javax_swing_text_html_HTML__24Tag$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_104[] = {
	&_jc_javax_swing_text_html_HTML__24UnknownTag$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[65]=	_jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_65,
	[101]=	_jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_101,
	[104]=	_jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_104,
	[113]=	_jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_text_html_HTML__24UnknownTag$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "javax/swing/text/html/HTML",	_JC_JLONG(0x57b76034fa05fce) },
	{ "javax/swing/text/html/HTML$Tag",	_JC_JLONG(0xe195b3a296492665) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_text_html_HTML__24UnknownTag$vtype _jc_javax_swing_text_html_HTML__24UnknownTag$type = {
    .type= {
	.name=			"javax/swing/text/html/HTML$UnknownTag",
	.superclass=		&_jc_javax_swing_text_html_HTML__24Tag$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_javax_swing_text_html_HTML__24UnknownTag$interfaces) / sizeof(*_jc_javax_swing_text_html_HTML__24UnknownTag$interfaces),
	.interfaces=		_jc_javax_swing_text_html_HTML__24UnknownTag$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x51da1f48373035e8),
		.source_file=		"HTML.java",
		.instance_size=		sizeof(_jc_javax_swing_text_html_HTML__24UnknownTag$refs) + sizeof(_jc_javax_swing_text_html_HTML__24UnknownTag$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_javax_swing_text_html_HTML__24UnknownTag$fields) / sizeof(*_jc_javax_swing_text_html_HTML__24UnknownTag$fields),
		.fields=		_jc_javax_swing_text_html_HTML__24UnknownTag$fields,
		.num_methods=		sizeof(_jc_javax_swing_text_html_HTML__24UnknownTag$methods) / sizeof(*_jc_javax_swing_text_html_HTML__24UnknownTag$methods),
		.methods=		_jc_javax_swing_text_html_HTML__24UnknownTag$methods,
		.instanceof_hash_table=	_jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_table,
		.class_fields=		&_jc_javax_swing_text_html_HTML__24UnknownTag$class_fields,
		.outer_class=		&_jc_javax_swing_text_html_HTML$type,
		.num_class_depends=		sizeof(_jc_javax_swing_text_html_HTML__24UnknownTag$class_depends) / sizeof(*_jc_javax_swing_text_html_HTML__24UnknownTag$class_depends),
		.class_depends=		_jc_javax_swing_text_html_HTML__24UnknownTag$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_text_html_HTML__24Tag= {
	},
	.javax_swing_text_html_HTML__24UnknownTag= {
	},
    }
};

==> jc-1.4.5.tar.gz: javax/swing/text/html/HTML__24UnknownTag.c <==
// public class javax.swing.text.html.HTML$UnknownTag

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class d1282e171465288b java_lang_Comparable
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 4f6ebb4b98e2af javax_swing_text_html_HTML
// @dep_class f9e1a7f884b6ed1e javax_swing_text_html_HTML__24Tag
// @dep_class 8afc8a722da27026 javax_swing_text_html_HTML__24UnknownTag

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_Comparable
// @dep_header java_lang_String
// @dep_header javax_swing_text_html_HTML
// @dep_header javax_swing_text_html_HTML__24UnknownTag

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/Comparable.h"
#include "java/lang/String.h"
#include "javax/swing/text/html/HTML.h"
#include "javax/swing/text/html/HTML__24UnknownTag.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private static final long serialVersionUID
static const jlong _jc_javax_swing_text_html_HTML__24UnknownTag$initial_value$serialVersionUID = _JC_JLONG(-1534369342247250625);
static _jc_field _jc_javax_swing_text_html_HTML__24UnknownTag$field_info$serialVersionUID = {
	.name=		"serialVersionUID",
	.signature=	"J",
	.class=		&_jc_javax_swing_text_html_HTML__24UnknownTag$type,
	.type=		&_jc_long$prim$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_text_html_HTML__24UnknownTag$fields_struct, serialVersionUID),
	.initial_value=	&_jc_javax_swing_text_html_HTML__24UnknownTag$initial_value$serialVersionUID,
};

// Fields
static _jc_field *const _jc_javax_swing_text_html_HTML__24UnknownTag$fields[] = {
	&_jc_javax_swing_text_html_HTML__24UnknownTag$field_info$serialVersionUID
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String)
//

static _jc_linenum _jc_javax_swing_text_html_HTML__24UnknownTag$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_javax_swing_text_html_HTML__24UnknownTag$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_swing_text_html_HTML__24UnknownTag$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_javax_swing_text_html_HTML__24UnknownTag$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_javax_swing_text_html_HTML__24UnknownTag$type,
	.param_types=		&_jc_javax_swing_text_html_HTML__24UnknownTag$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_text_html_HTML__24UnknownTag$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_text_html_HTML__24UnknownTag$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_text_html_HTML__24UnknownTag$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_text_html_HTML__24UnknownTag, _init$c31b894660454d13);

void _JC_JCNI_ATTR
_jc_javax_swing_text_html_HTML__24UnknownTag$method$_init$c31b894660454d13(_jc_env *const env, _jc_javax_swing_text_html_HTML__24UnknownTag$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_javax_swing_text_html_HTML__24UnknownTag$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	r1 = param0;
	_JC_REF_FIELD(env, r0, javax_swing_text_html_HTML__24Tag, name) = r1;
	_JC_PRIM_FIELD(env, r0, javax_swing_text_html_HTML__24Tag, flags) = 0;
	_JC_LINE_NUMBER(1160);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_text_html_HTML__24UnknownTag$methods[] = {
	&_jc_javax_swing_text_html_HTML__24UnknownTag$method_info$_init$c31b894660454d13
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_javax_swing_text_html_HTML__24UnknownTag$fields_struct _jc_javax_swing_text_html_HTML__24UnknownTag$class_fields = { };

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_javax_swing_text_html_HTML__24UnknownTag$interfaces[] = {
	&_jc_java_io_Serializable$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_javax_swing_text_html_HTML__24UnknownTag$imethod_hash_bucket_35[] = {
	&_jc_javax_swing_text_html_HTML__24Tag$method_info$compareTo$84fc6fc4a23c98a3,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_javax_swing_text_html_HTML__24UnknownTag$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[35]=	_jc_javax_swing_text_html_HTML__24UnknownTag$imethod_hash_bucket_35
};

// Interface "quick" lookup hash table
static const void *_jc_javax_swing_text_html_HTML__24UnknownTag$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[35]=	&_jc_javax_swing_text_html_HTML__24Tag$method$compareTo$84fc6fc4a23c98a3
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_11[] = {
	&_jc_java_lang_Comparable$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_30[] = {
	&_jc_javax_swing_text_html_HTML__24Tag$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_38[] = {
	&_jc_javax_swing_text_html_HTML__24UnknownTag$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[11]=	_jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_11,
	[30]=	_jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_30,
	[38]=	_jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_38,
	[65]=	_jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_65,
	[101]=	_jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_text_html_HTML__24UnknownTag$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Comparable",	_JC_JLONG(0xd1282e171465288b) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "javax/swing/text/html/HTML",	_JC_JLONG(0x4f6ebb4b98e2af) },
	{ "javax/swing/text/html/HTML$Tag",	_JC_JLONG(0xf9e1a7f884b6ed1e) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_text_html_HTML__24UnknownTag$vtype _jc_javax_swing_text_html_HTML__24UnknownTag$type = {
    .type= {
	.name=			"javax/swing/text/html/HTML$UnknownTag",
	.superclass=		&_jc_javax_swing_text_html_HTML__24Tag$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_javax_swing_text_html_HTML__24UnknownTag$interfaces) / sizeof(*_jc_javax_swing_text_html_HTML__24UnknownTag$interfaces),
	.interfaces=		_jc_javax_swing_text_html_HTML__24UnknownTag$interfaces,
	.imethod_hash_table=	_jc_javax_swing_text_html_HTML__24UnknownTag$imethod_hash_table,
	.imethod_quick_table=	_jc_javax_swing_text_html_HTML__24UnknownTag$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		19,
		.hash=			_JC_JLONG(0x8afc8a722da27026),
		.source_file=		"HTML.java",
		.instance_size=		sizeof(_jc_javax_swing_text_html_HTML__24UnknownTag$refs) + sizeof(_jc_javax_swing_text_html_HTML__24UnknownTag$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_javax_swing_text_html_HTML__24UnknownTag$fields) / sizeof(*_jc_javax_swing_text_html_HTML__24UnknownTag$fields),
		.fields=		_jc_javax_swing_text_html_HTML__24UnknownTag$fields,
		.num_methods=		sizeof(_jc_javax_swing_text_html_HTML__24UnknownTag$methods) / sizeof(*_jc_javax_swing_text_html_HTML__24UnknownTag$methods),
		.methods=		_jc_javax_swing_text_html_HTML__24UnknownTag$methods,
		.instanceof_hash_table=	_jc_javax_swing_text_html_HTML__24UnknownTag$instanceof_hash_table,
		.class_fields=		&_jc_javax_swing_text_html_HTML__24UnknownTag$class_fields,
		.outer_class=		&_jc_javax_swing_text_html_HTML$type,
		.num_class_depends=		sizeof(_jc_javax_swing_text_html_HTML__24UnknownTag$class_depends) / sizeof(*_jc_javax_swing_text_html_HTML__24UnknownTag$class_depends),
		.class_depends=		_jc_javax_swing_text_html_HTML__24UnknownTag$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=			// overridden
		&_jc_javax_swing_text_html_HTML__24Tag$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=			// overridden
		&_jc_javax_swing_text_html_HTML__24Tag$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_javax_swing_text_html_HTML__24Tag$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_text_html_HTML__24Tag= {
	    .breaksFlow$a0ac881aedc1d6c2=
		&_jc_javax_swing_text_html_HTML__24Tag$method$breaksFlow$a0ac881aedc1d6c2,
	    .compareTo$84fc6fc4a23c98a3=
		&_jc_javax_swing_text_html_HTML__24Tag$method$compareTo$84fc6fc4a23c98a3,
	    .equals$8a15e0625571c581=
		&_jc_javax_swing_text_html_HTML__24Tag$method$equals$8a15e0625571c581,
	    .hashCode$53152098849316df=
		&_jc_javax_swing_text_html_HTML__24Tag$method$hashCode$53152098849316df,
	    .isBlock$4aad414cca945ab1=
		&_jc_javax_swing_text_html_HTML__24Tag$method$isBlock$4aad414cca945ab1,
	    .isPreformatted$4b78ae8ea869b399=
		&_jc_javax_swing_text_html_HTML__24Tag$method$isPreformatted$4b78ae8ea869b399,
	    .isSyntetic$d0f4870792d28783=
		&_jc_javax_swing_text_html_HTML__24Tag$method$isSyntetic$d0f4870792d28783,
	    .toString$7ea43b33b80a3070=
		&_jc_javax_swing_text_html_HTML__24Tag$method$toString$7ea43b33b80a3070,
	},
	.javax_swing_text_html_HTML__24UnknownTag= {
	},
    }
};
